==> phpAdsNew-2.0.tar.gz: phpAdsNew-2.0/language/italian/invocation.lang.php <==
<?php // $Revision: 2.2.2.3 $

/************************************************************************/
/* phpAdsNew 2                                                          */
/* ===========                                                          */
/*                                                                      */
/* Copyright (c) 2000-2003 by the phpAdsNew developers                  */
/* http://sourceforge.net/projects/phpadsnew                            */
/*                                                                      */
/* Translations by Matteo Beccati                                       */
/*                                                                      */
/* This program is free software. You can redistribute it and/or modify */
/* it under the terms of the GNU General Public License as published by */
/* the Free Software Foundation; either version 2 of the License.       */
/************************************************************************/

// Invocation Types
$GLOBALS['strInvocationRemote']			= "Invocazione remota";
$GLOBALS['strInvocationJS']				= "Invocazione remota con Javascript";
$GLOBALS['strInvocationIframes']		= "Invocazione remota con iframes";
$GLOBALS['strInvocationXmlRpc']			= "Invocazione remota con XML-RPC";
$GLOBALS['strInvocationCombined']		= "Invocazione remota Combinata";
$GLOBALS['strInvocationPopUp']			= "Popup";
$GLOBALS['strInvocationAdLayer']		= "Interstiziale o DHTML floating";
$GLOBALS['strInvocationLocal']			= "Modo locale";


// Other
$GLOBALS['strCopyToClipboard']			= "Copia negli appunti";


// Measures
$GLOBALS['strAbbrPixels']				= "px";
$GLOBALS['strAbbrSeconds']				= "sec";


// Common Invocation Parameters
$GLOBALS['strInvocationWhat']			= "Selezione banner";
$GLOBALS['strInvocationClientID']		= "Inserzionista o campagna";
$GLOBALS['strInvocationTarget']			= "Frame destinazione";
$GLOBALS['strInvocationSource']			= "Sorgente";
$GLOBALS['strInvocationWithText']		= "Link testuale sotto il Banner";
$GLOBALS['strInvocationDontShowAgain']	= "Non mostrare banner duplicati nella stessa pagina";
$GLOBALS['strInvocationDontShowAgainCampaign'] = "Non mostrare banner della stessa campagna nella pagina";
$GLOBALS['strInvocationTemplate'] 		= "Assegna il banner a una variabile per utilizzarla in un template";


// Iframe
$GLOBALS['strIFrameRefreshAfter']		= "Aggiorna dopo";
$GLOBALS['strIframeResizeToBanner']		= "Adatta dimensioni IFrame al Banner";
$GLOBALS['strIframeMakeTransparent']	= "Sfondo IFrame trasparente";
$GLOBALS['strIframeIncludeNetscape4']	= "Includi ilayer compatibile con Netscape 4";


// PopUp
$GLOBALS['strPopUpStyle']				= "Tipo di Pop-up";
$GLOBALS['strPopUpStylePopUp']			= "Pop-up";
$GLOBALS['strPopUpStylePopUnder']		= "Pop-under";
$GLOBALS['strPopUpCreateInstance']		= "Apertura Pop-up";
$GLOBALS['strPopUpImmediately']			= "Immediata";
$GLOBALS['strPopUpOnClose']				= "Alla chiusura della pagina";
$GLOBALS['strPopUpAfterSec']			= "Dopo";
$GLOBALS['strAutoCloseAfter']			= "Chiudi automaticamente dopo";
$GLOBALS['strPopUpTop']					= "Positione Iniziale (alto)";
$GLOBALS['strPopUpLeft']				= "Positione Iniziale (sinistra)";
$GLOBALS['strWindowOptions']			= "Opzioni finestra";
$GLOBALS['strShowToolbars']				= "Barra degli strumenti";
$GLOBALS['strShowLocation']				= "Barra dell'indirizzo";
$GLOBALS['strShowMenubar']				= "Barra dei menu";
$GLOBALS['strShowStatus']				= "Barra di stato";
$GLOBALS['strWindowResizable']			= "Ridimensionabile";
$GLOBALS['strShowScrollbars']			= "Barre di scorrimento";


// XML-RPC
$GLOBALS['strXmlRpcLanguage']			= "Linguaggio utilizzato";


// AdLayer
$GLOBALS['strAdLayerStyle']				= "Stile";

$GLOBALS['strAlignment']				= "Allinemento";
$GLOBALS['strHAlignment']				= "Allinemento orizzontale";
$GLOBALS['strLeft']						= "Sinistra";
$GLOBALS['strCenter']					= "Centrato";
$GLOBALS['strRight']					= "Destra";

$GLOBALS['strVAlignment']				= "Allinemento verticale";
$GLOBALS['strTop']						= "Alto";
$GLOBALS['strMiddle']					= "Centrato";
$GLOBALS['strBottom']					= "Basso";

$GLOBALS['strAutoCollapseAfter']		= "Riduci automaticamente dopo";
$GLOBALS['strCloseText']				= "Testo di chiusura";
$GLOBALS['strClose']					= "[Chiudi]";
$GLOBALS['strBannerPadding']			= "Margini interni";

$GLOBALS['strHShift']					= "Scostamento orizzontale";
$GLOBALS['strVShift']					= "Scostamento verticale";

$GLOBALS['strShowCloseButton']			= "Visualizza pulsante di chiusura";
$GLOBALS['strBackgroundColor']			= "Colore di sfondo";
$GLOBALS['strBorderColor']				= "Colore del bordo";

$GLOBALS['strDirection']				= "Direzione";
$GLOBALS['strLeftToRight']				= "Da sinistra a destra";
$GLOBALS['strRightToLeft']				= "Da destra a sinistra";
$GLOBALS['strLooping']					= "Ripetizioni";
$GLOBALS['strAlwaysActive']				= "Sempre attivo";
$GLOBALS['strSpeed']					= "Velocit&agrave;";
$GLOBALS['strPause']					= "Pausa";
$GLOBALS['strLimited']					= "Limitato";
$GLOBALS['strLeftMargin']				= "Margine sinistro";
$GLOBALS['strRightMargin']				= "Margine destro";
$GLOBALS['strTransparentBackground']	= "Sfondo trasparente";

$GLOBALS['strSmoothMovement']			= "Movimento fluido";
$GLOBALS['strHideNotMoving']			= "Nascondi il banner quando il puntatore &egrave; fermo";
$GLOBALS['strHideDelay']				= "Nascondi dopo";
$GLOBALS['strHideTransparancy']			= "Trasparenza del banner nascosto";


$GLOBALS['strAdLayerStyleName']	= array(
	'geocities'		=> "Geocities",
	'simple'		=> "Semplice",
	'cursor'		=> "Puntatore",
	'floater'		=> "Banner volante"
);

?>

==> phpAdsNew-2.0.7.tar.gz: phpAdsNew-2.0.7/language/italian/invocation.lang.php <==
<?php // $Revision: 2.2.2.5 $

/************************************************************************/
/* phpAdsNew 2                                                          */
/* ===========                                                          */
/*                                                                      */
/* Copyright (c) 2000-2005 by the phpAdsNew developers                  */
/* http://sourceforge.net/projects/phpadsnew                            */
/*                                                                      */
/* Translations by Matteo Beccati                                       */
/*                                                                      */
/* This program is free software. You can redistribute it and/or modify */
/* it under the terms of the GNU General Public License as published by */
/* the Free Software Foundation; either version 2 of the License.       */
/************************************************************************/

// Invocation Types
$GLOBALS['strInvocationRemote']			= "Invocazione remota";
$GLOBALS['strInvocationJS']				= "Invocazione remota con Javascript";
$GLOBALS['strInvocationIframes']		= "Invocazione remota con iframes";
$GLOBALS['strInvocationXmlRpc']			= "Invocazione remota con XML-RPC";
$GLOBALS['strInvocationCombined']		= "Invocazione remota Combinata";
$GLOBALS['strInvocationPopUp']			= "Popup";
$GLOBALS['strInvocationAdLayer']		= "Interstiziale o DHTML floating";
$GLOBALS['strInvocationLocal']			= "Modo locale";


// Other
$GLOBALS['strCopyToClipboard']			= "Copia negli appunti";


// Measures
$GLOBALS['strAbbrPixels']				= "px";
$GLOBALS['strAbbrSeconds']				= "sec";


// Common Invocation Parameters
$GLOBALS['strInvocationWhat']			= "Selezione banner";
$GLOBALS['strInvocationClientID']		= "Inserzionista o campagna";
$GLOBALS['strInvocationTarget']			= "Frame destinazione";
$GLOBALS['strInvocationSource']			= "Sorgente";
$GLOBALS['strInvocationWithText']		= "Link testuale sotto il Banner";
$GLOBALS['strInvocationDontShowAgain']	= "Non mostrare banner duplicati nella stessa pagina";
$GLOBALS['strInvocationDontShowAgainCampaign'] = "Non mostrare banner della stessa campagna nella pagina";
$GLOBALS['strInvocationTemplate'] 		= "Assegna il banner a una variabile per utilizzarla in un template";


// Iframe
$GLOBALS['strIFrameRefreshAfter']		= "Aggiorna dopo";
$GLOBALS['strIframeResizeToBanner']		= "Adatta dimensioni IFrame al Banner";
$GLOBALS['strIframeMakeTransparent']	= "Sfondo IFrame trasparente";
$GLOBALS['strIframeIncludeNetscape4']	= "Includi ilayer compatibile con Netscape 4";


// PopUp
$GLOBALS['strPopUpStyle']				= "Tipo di Pop-up";
$GLOBALS['strPopUpStylePopUp']			= "Pop-up";
$GLOBALS['strPopUpStylePopUnder']		= "Pop-under";
$GLOBALS['strPopUpCreateInstance']		= "Apertura Pop-up";
$GLOBALS['strPopUpImmediately']			= "Immediata";
$GLOBALS['strPopUpOnClose']				= "Alla chiusura della pagina";
$GLOBALS['strPopUpAfterSec']			= "Dopo";
$GLOBALS['strAutoCloseAfter']			= "Chiudi automaticamente dopo";
$GLOBALS['strWindowOptions']			= "Opzioni finestra";
$GLOBALS['strShowToolbars']				= "Barre degli strumenti";
$GLOBALS['strShowLocation']				= "Barra dell'indirizzo";
$GLOBALS['strShowMenubar']				= "Barra dei menu";
$GLOBALS['strShowStatus']				= "Barra di stato";
$GLOBALS['strWindowResizable']			= "Ridimensionabile";
$GLOBALS['strShowScrollbars']			= "Barre di scorrimento";
$GLOBALS['strPopUpTop']					= "Positione Iniziale (alto)";
$GLOBALS['strPopUpLeft']				= "Positione Iniziale (sinistra)";
$GLOBALS['strPopupFromLeft']			= "dal lato sinistro dello schermo";
$GLOBALS['strPopupFromRight']			= "dal lato destro dello schermo";
$GLOBALS['strPopupFromTop']				= "dal lato superiore dello schermo";
$GLOBALS['strPopupFromBottom']			= "dal lato inferiore dello schermo";
$GLOBALS['strPopupCentered']			= "Centrato";


// XML-RPC
$GLOBALS['strXmlRpcLanguage']			= "Linguaggio utilizzato";


// AdLayer
$GLOBALS['strAdLayerStyle']				= "Stile";

$GLOBALS['strAlignment']				= "Allinemento";
$GLOBALS['strHAlignment']				= "Allinemento orizzontale";
$GLOBALS['strLeft']						= "Sinistra";
$GLOBALS['strCenter']					= "Centrato";
$GLOBALS['strRight']					= "Destra";

$GLOBALS['strVAlignment']				= "Allinemento verticale";
$GLOBALS['strTop']						= "Alto";
$GLOBALS['strMiddle']					= "Centrato";
$GLOBALS['strBottom']					= "Basso";

$GLOBALS['strAutoCollapseAfter']		= "Riduci automaticamente dopo";
$GLOBALS['strCloseText']				= "Testo di chiusura";
$GLOBALS['strClose']					= "[Chiudi]";
$GLOBALS['strBannerPadding']			= "Margini interni";

$GLOBALS['strHShift']					= "Scostamento orizzontale";
$GLOBALS['strVShift']					= "Scostamento verticale";

$GLOBALS['strShowCloseButton']			= "Visualizza pulsante di chiusura";
$GLOBALS['strBackgroundColor']			= "Colore di sfondo";
$GLOBALS['strBorderColor']				= "Colore del bordo";

$GLOBALS['strDirection']				= "Direzione";
$GLOBALS['strLeftToRight']				= "Da sinistra a destra";
$GLOBALS['strRightToLeft']				= "Da destra a sinistra";
$GLOBALS['strLooping']					= "Ripetizioni";
$GLOBALS['strAlwaysActive']				= "Sempre attivo";
$GLOBALS['strSpeed']					= "Velocit&agrave;";
$GLOBALS['strPause']					= "Pausa";
$GLOBALS['strLimited']					= "Limitato";
$GLOBALS['strLeftMargin']				= "Margine sinistro";
$GLOBALS['strRightMargin']				= "Margine destro";
$GLOBALS['strTransparentBackground']	= "Sfondo trasparente";

$GLOBALS['strSmoothMovement']			= "Movimento fluido";
$GLOBALS['strHideNotMoving']			= "Nascondi il banner quando il puntatore &egrave; fermo";
$GLOBALS['strHideDelay']				= "Nascondi dopo";
$GLOBALS['strHideTransparancy']			= "Trasparenza del banner nascosto";


$GLOBALS['strAdLayerStyleName']	= array(
	'geocities'		=> "Geocities",
	'simple'		=> "Semplice",
	'cursor'		=> "Puntatore",
	'floater'		=> "Banner volante"
);

?>
